OperatorKind

Enum OperatorKind 

#[non_exhaustive]
pub enum OperatorKind {
Show 44 variants MatMul, ArgMax { axis: i32, nan_mode: NanPropagationMode, }, Ceil, Floor, Clamp { min_val: [u8; 8], max_val: [u8; 8], bound_bytes: u8, nan_mode: NanPropagationMode, }, Concat { axis: i32, }, Reverse { axis: i32, }, Transpose { perms: [i32; 6], rank: u8, }, ReduceMax { axis: i32, nan_mode: NanPropagationMode, }, ReduceMin { axis: i32, nan_mode: NanPropagationMode, }, ReduceProduct { axis: i32, }, ReduceSum { axis: i32, }, MaxPool2d { kernel: [i32; 2], stride: [i32; 2], pad: [i32; 4], nan_mode: NanPropagationMode, }, Sigmoid, Tanh, Add, LogicalAnd, LogicalOr, LogicalXor, Maximum { nan_mode: NanPropagationMode, }, Minimum { nan_mode: NanPropagationMode, }, Mul, Pow, Sub, Abs, Cos, Exp, Log, LogicalNot, Negate, Reciprocal, Rsqrt, Sin, Select, Equal, Greater, GreaterEqual, Erf, Reshape, Cast, Rescale { scale32: bool, rounding_mode: RoundingMode, per_channel: bool, input_unsigned: bool, output_unsigned: bool, }, Const, Identity, ConstShape,
}

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


MatMul



ArgMax

Fields

axis: i32


Ceil



Floor



Clamp

The bounds are one scalar each in the operand’s own dtype, so they are carried as their serialized bytes (bound_bytes of each array is significant) rather than a wider type that would not represent an integer or FP8 bound faithfully.

Fields

min_val: [u8; 8]
max_val: [u8; 8]
bound_bytes: u8


Concat

Fields

axis: i32


Reverse

Fields

axis: i32


Transpose

One permutation entry per dimension; rank of perms is significant.

Fields

perms: [i32; 6]
rank: u8


ReduceMax

Fields

axis: i32


ReduceMin

Fields

axis: i32


ReduceProduct

Fields

axis: i32


ReduceSum

Fields

axis: i32


MaxPool2d

Fields

kernel: [i32; 2]
stride: [i32; 2]
pad: [i32; 4]


Sigmoid



Tanh



Add



LogicalAnd



LogicalOr



LogicalXor



Maximum

Fields



Minimum

Fields



Mul



Pow



Sub



Abs



Cos



Exp



Log



LogicalNot



Negate



Reciprocal



Rsqrt



Sin



Select



Equal



Greater



GreaterEqual



Erf



Reshape



Cast



Rescale

Fields

scale32: bool
rounding_mode: RoundingMode
per_channel: bool
input_unsigned: bool
output_unsigned: bool


Const



Identity



ConstShape

Implementations

Source

impl OperatorKind

pub const fn op(self) -> Op

Stable TOSA opcode selected by this typed variant.